@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -95,6 +95,7 @@ public class PublicationWriterTest extends TestCase {
         publication.setTarget(target);
         publication.setConfiguration(config);
         publication.setDisplayName("myName");
+        publication.setEnabled(true);
     }
     
     public void testWriteObject() throws JSONException, PublicationJSONException {
@@ -106,6 +107,7 @@ public class PublicationWriterTest extends TestCase {
                 .hasKey("entity").withValueObject()
                     .hasKey("folder").withValue("12")
                     .objectEnds()
+                .hasKey("enabled").withValue(true)
                 .hasKey("entityModule").withValue("oranges")
                 .hasKey("target").withValue("com.openexchange.publish.test")
                 .hasKey("displayName").withValue("myName")
@@ -121,7 +123,7 @@ public class PublicationWriterTest extends TestCase {
     
     public void testWriteArray() throws JSONException, PublicationJSONException {
         Map<String, String[]> specialCols = new HashMap<String, String[]>();
-        String[] basicCols = new String[] { "id", "target", "displayName" };
+        String[] basicCols = new String[] { "id", "target", "displayName", "enabled" };
         specialCols.put("com.openexchange.publish.test", new String[] { "siteName" });
         
         JSONArray array = new PublicationWriter().writeArray(
@@ -130,7 +132,7 @@ public class PublicationWriterTest extends TestCase {
             specialCols,
             Arrays.asList("com.openexchange.publish.test"), publication.getTarget().getFormDescription());
 
-        JSONAssertion assertion = new JSONAssertion().isArray().withValues(23, "com.openexchange.publish.test", "myName", "publication");
+        JSONAssertion assertion = new JSONAssertion().isArray().withValues(23, "com.openexchange.publish.test", "myName", true, "publication");
 
         assertValidates(assertion, array);
         
